@@ -1,9 +1,11 @@
 use arrow::array::{ListArray, Utf8Array};
 
 pub use crate::array::default_arrays::*;
+pub use crate::array::*;
 pub use crate::bitmap::mutable::MutableBitmapExtension;
+pub use crate::data_types::*;
+pub use crate::index::*;
 pub use crate::kernels::rolling::no_nulls::QuantileInterpolOptions;
-pub use crate::{array::*, data_types::*, index::*};
 
 pub type LargeStringArray = Utf8Array<i64>;
 pub type LargeListArray = ListArray<i64>;
