@@ -68,7 +68,7 @@ use serde::{Deserialize, Serialize};
 pub use write::CsvWriter;
 
 use crate::aggregations::ScanAggregation;
-use crate::csv::read_impl::{cast_columns, CoreReader};
+use crate::csv::read_impl::CoreReader;
 use crate::csv::utils::get_reader_bytes;
 use crate::mmap::MmapBytesReader;
 use crate::predicates::PhysicalIoExpr;
