@@ -8,9 +8,12 @@ mod truncate;
 mod upsample;
 mod windows;
 
+pub use date_range::*;
 #[cfg(any(feature = "dtype-date", feature = "dtype-datetime"))]
 pub use groupby::dynamic::*;
-pub use {
-    date_range::*, truncate::*, upsample::*, windows::calendar::date_range as date_range_vec,
-    windows::duration::Duration, windows::groupby::ClosedWindow, windows::window::Window,
-};
+pub use truncate::*;
+pub use upsample::*;
+pub use windows::calendar::date_range as date_range_vec;
+pub use windows::duration::Duration;
+pub use windows::groupby::ClosedWindow;
+pub use windows::window::Window;
