@@ -1,10 +1,12 @@
 from __future__ import annotations
 
+import os
 import random
 import warnings
 from dataclasses import dataclass
 from datetime import datetime, timedelta
 from functools import reduce
+from math import isfinite
 from typing import Any, Sequence
 
 try:
@@ -59,26 +61,28 @@ from polars.datatypes import (
 )
 
 if HYPOTHESIS_INSTALLED:
-    # TODO: increase the number of iterations during CI checkins?
-    # https://hypothesis.readthedocs.io/en/latest/settings.html#settings-profiles
-    common_settings = {"print_blob": True, "deadline": timedelta(milliseconds=300)}
+    # Default profile (eg: running locally)
+    common_settings = {"print_blob": True, "deadline": None}
     settings.register_profile(
         name="polars.default",
         max_examples=100,
         **common_settings,  # type: ignore[arg-type]
     )
+    # CI 'max' profile (10x the number of iterations).
+    # this is expensive, and not actually enabled in
+    # our usual CI pipeline; requires explicit opt-in.
     settings.register_profile(
         name="polars.ci",
-        max_examples=500,
+        max_examples=1000,
         **common_settings,  # type: ignore[arg-type]
     )
-    # if os.getenv("CI")
-    #   settings.load_profile("polars.ci")
-    # else:
-    settings.load_profile("polars.default")
+    if os.getenv("CI_MAX"):
+        settings.load_profile("polars.ci")
+    else:
+        settings.load_profile("polars.default")
 
 
-MAX_DATA_SIZE = 20
+MAX_DATA_SIZE = 10
 MAX_COLS = 8
 
 
@@ -348,13 +352,16 @@ if HYPOTHESIS_INSTALLED:
         UInt64: integers(min_value=0, max_value=(2**64) - 1),
         # TODO: when generating text for categorical, ensure there are repeats -
         #  don't want all to be unique.
-        Categorical: text(),
-        Utf8: text(),
+        Categorical: text(max_size=10),
+        Utf8: text(max_size=10),
         # TODO: generate arrow temporal types with different resolution (32/64) to
         #  validate compatibility.
         Time: times(),
         Date: dates(),
-        Duration: timedeltas(),
+        Duration: timedeltas(
+            min_value=timedelta(microseconds=-(2**63)),
+            max_value=timedelta(microseconds=(2**63) - 1),
+        ),
         # TODO: confirm datetime min/max limits with different timeunit granularity.
         # TODO: specific strategies for temporal dtypes with timeunits.
         Datetime: datetimes(min_value=datetime(1970, 1, 1)),
@@ -547,7 +554,9 @@ if HYPOTHESIS_INSTALLED:
         max_size: int | None = MAX_DATA_SIZE,
         strategy: SearchStrategy[object] | None = None,
         null_probability: float = 0.0,
+        allow_infinities: bool = True,
         unique: bool = False,
+        chunked: bool | None = None,
         allowed_dtypes: Sequence[PolarsDataType] | None = None,
         excluded_dtypes: Sequence[PolarsDataType] | None = None,
     ) -> SearchStrategy[pli.Series]:
@@ -562,23 +571,26 @@ if HYPOTHESIS_INSTALLED:
         dtype : dtype, optional
             a valid polars DataType for the resulting series.
         size : int, optional
-            if set, will create a Series of exactly this size (and ignore min/max len
-            params).
+            if set, creates a Series of exactly this size (ignoring min/max params).
         min_size : int, optional
             if not passing an exact size, can set a minimum here (defaults to 0).
             no-op if `size` is set.
         max_size : int, optional
             if not passing an exact size, can set a maximum value here (defaults to
-            MAX_DATA_SIZE).
-            no-op if `size` is set.
+            MAX_DATA_SIZE). no-op if `size` is set.
         strategy : strategy, optional
             supports overriding the default strategy for the given dtype.
         null_probability : float, optional
             percentage chance (expressed between 0.0 => 1.0) that a generated value is
             None. this is applied independently of any None values generated by the
             underlying strategy.
+        allow_infinities : bool, optional
+            optionally disallow generation of +/-inf values for floating-point dtypes.
         unique : bool, optional
             indicate whether Series values should all be distinct.
+        chunked : bool, optional
+            ensure that Series with more than one element have ``n_chunks`` > 1.
+            if omitted, chunking is applied at random.
         allowed_dtypes : {list,set}, optional
             when automatically generating Series data, allow only these dtypes.
         excluded_dtypes : {list,set}, optional
@@ -634,6 +646,10 @@ if HYPOTHESIS_INSTALLED:
                 draw(sampled_from(selectable_dtypes)) if dtype is None else dtype
             )
             dtype_strategy = strategy or dtype_strategy_mapping[series_dtype]
+            if series_dtype in (Float32, Float64) and not allow_infinities:
+                dtype_strategy = dtype_strategy.filter(
+                    lambda x: not isinstance(x, float) or isfinite(x)
+                )
 
             # create/assign series size
             series_size = (
@@ -643,18 +659,18 @@ if HYPOTHESIS_INSTALLED:
                 if size is None
                 else size
             )
-
             # assign series name
             series_name = name if isinstance(name, str) or name is None else draw(name)
 
             # create series using dtype-specific strategy to generate values
-
             if series_size == 0:
                 series_values = []
+            elif null_probability == 1:
+                series_values = [None] * series_size
             else:
                 series_values = draw(
                     lists(
-                        dtype_strategy,
+                        dtype_strategy,  # type: ignore[arg-type]
                         min_size=series_size,
                         max_size=series_size,
                         unique=unique,
@@ -662,9 +678,10 @@ if HYPOTHESIS_INSTALLED:
                 )
 
             # apply null values (custom frequency)
-            for idx in range(series_size):
-                if random.random() < null_probability:
-                    series_values[idx] = None
+            if null_probability and null_probability != 1:
+                for idx in range(series_size):
+                    if random.random() < null_probability:
+                        series_values[idx] = None
 
             # init series with strategy-generated data
             s = pli.Series(
@@ -674,6 +691,10 @@ if HYPOTHESIS_INSTALLED:
             )
             if is_categorical_dtype(dtype):
                 s = s.cast(Categorical)
+            if series_size:
+                if chunked or (chunked is None and draw(booleans())):
+                    split_at = series_size // 2
+                    s = s[:split_at].append(s[split_at:], append_chunks=True)
             return s
 
         return draw_series()
@@ -688,8 +709,10 @@ if HYPOTHESIS_INSTALLED:
         size: int | None = None,
         min_size: int | None = 0,
         max_size: int | None = MAX_DATA_SIZE,
+        chunked: bool | None = None,
         include_cols: Sequence[column] | None = None,
         null_probability: float | dict[str, float] = 0.0,
+        allow_infinities: bool = True,
         allowed_dtypes: Sequence[PolarsDataType] | None = None,
         excluded_dtypes: Sequence[PolarsDataType] | None = None,
     ) -> SearchStrategy[pli.DataFrame | pli.LazyFrame]:
@@ -717,6 +740,9 @@ if HYPOTHESIS_INSTALLED:
         max_size : int, optional
             if not passing an exact size, set the maximum number of rows in the
             DataFrame.
+        chunked : bool, optional
+            ensure that DataFrames with more than row have ``n_chunks`` > 1. if
+            omitted, chunking will be randomised at the level of individual Series.
         include_cols : [column], optional
             a list of `column` objects to include in the generated DataFrame. note that
             explicitly provided columns are appended onto the list of existing columns
@@ -725,8 +751,10 @@ if HYPOTHESIS_INSTALLED:
             percentage chance (expressed between 0.0 => 1.0) that a generated value is
             None. this is applied independently of any None values generated by the
             underlying strategy, and can be applied either on a per-column basis (if
-            given as a {col:pct} dict), or globally. if null_probability is defined on a
-            column, it takes precedence over the global value.
+            given as a ``{col:pct}`` dict), or globally. if null_probability is defined
+            on a column, it takes precedence over the global value.
+        allow_infinities : bool, optional
+            optionally disallow generation of +/-inf values for floating-point dtypes.
         allowed_dtypes : {list,set}, optional
             when automatically generating data, allow only these dtypes.
         excluded_dtypes : {list,set}, optional
@@ -735,10 +763,10 @@ if HYPOTHESIS_INSTALLED:
         Notes
         -----
         In actual usage this is deployed as a unit test decorator, providing a strategy
-        that generates DataFrames or LazyFrames with the given schema/size
-        characteristics for the unit test. While developing a strategy/test, it can also
-        be useful to call `.example()` directly on a given strategy to see concrete
-        instances of the generated data.
+        that generates DataFrames or LazyFrames with the given characteristics for
+        the unit test. While developing a strategy/test, it can also be useful to
+        call `.example()` directly on a given strategy to see concrete instances of
+        the generated data.
 
         Examples
         --------
@@ -784,6 +812,9 @@ if HYPOTHESIS_INSTALLED:
         """  # noqa: 501
         if isinstance(cols, int):
             cols = columns(cols)
+        if isinstance(min_size, int):
+            if min_cols in (0, None):
+                min_cols = 1
 
         selectable_dtypes = [
             dtype
@@ -808,7 +839,7 @@ if HYPOTHESIS_INSTALLED:
             # append any explicitly provided cols
             coldefs.extend(include_cols or ())
 
-            # if not given, assign dataframe/series size
+            # assign dataframe/series size
             series_size = (
                 between(
                     draw, int, min_=(min_size or 0), max_=(max_size or MAX_DATA_SIZE)
@@ -838,15 +869,22 @@ if HYPOTHESIS_INSTALLED:
                             dtype=c.dtype,
                             size=series_size,
                             null_probability=(c.null_probability or 0.0),
+                            allow_infinities=allow_infinities,
                             strategy=c.strategy,
                             unique=c.unique,
+                            chunked=(chunked is None and draw(booleans())),
                         )
                     )
                     for c in coldefs
                 },
                 columns=frame_columns,  # type: ignore[arg-type]
             )
-            # if indicated, make lazy
+            # optionally generate frames with n_chunks > 1
+            if series_size > 1 and chunked is True:
+                split_at = series_size // 2
+                df = df[:split_at].vstack(df[split_at:])
+
+            # optionally make lazy
             return df.lazy() if lazy else df
 
         return draw_frames()
@@ -855,7 +893,17 @@ if HYPOTHESIS_INSTALLED:
 def assert_frame_equal_local_categoricals(
     df_a: pli.DataFrame, df_b: pli.DataFrame
 ) -> None:
-    assert df_a.schema == df_b.schema
+
+    for ((a_name, a_value), (b_name, b_value)) in zip(
+        df_a.schema.items(), df_b.schema.items()
+    ):
+        if a_name != b_name:
+            print(f"{a_name} != {b_name}")
+            raise AssertionError
+        if a_value != b_value:
+            print(f"{a_value} != {b_value}")
+            raise AssertionError
+
     cat_to_str = pli.col(Categorical).cast(str)
     assert df_a.with_column(cat_to_str).frame_equal(df_b.with_column(cat_to_str))
     cat_to_phys = pli.col(Categorical).to_physical()
