@@ -211,17 +211,29 @@ def _to_python_datetime(
         dt += timedelta(seconds=value * 3600 * 24)
         return dt.date()
     elif dtype == Datetime:
-        if tu == "ns":
-            # nanoseconds to seconds
-            dt = EPOCH + timedelta(microseconds=value / 1000)
-        elif tu == "us":
-            dt = EPOCH + timedelta(microseconds=value)
-        elif tu == "ms":
-            # milliseconds to seconds
-            dt = datetime.utcfromtimestamp(value / 1000)
+        if tz is None or tz == "" or tz == "UTC":
+            if tu == "ns":
+                # nanoseconds to seconds
+                dt = EPOCH + timedelta(microseconds=value / 1000)
+            elif tu == "us":
+                dt = EPOCH + timedelta(microseconds=value)
+            elif tu == "ms":
+                # milliseconds to seconds
+                dt = datetime.utcfromtimestamp(value / 1000)
+            else:
+                raise ValueError(f"tu must be one of {{'ns', 'us', 'ms'}}, got {tu}")
         else:
-            raise ValueError(f"tu must be one of {{'ns', 'us', 'ms'}}, got {tu}")
-        if tz is not None and len(tz) > 0:
+            if tu == "ns":
+                # nanoseconds to seconds
+                dt = datetime.fromtimestamp(0) + timedelta(microseconds=value / 1000)
+            elif tu == "us":
+                dt = datetime.fromtimestamp(0) + timedelta(microseconds=value)
+            elif tu == "ms":
+                # milliseconds to seconds
+                dt = datetime.fromtimestamp(value / 1000)
+            else:
+                raise ValueError(f"tu must be one of {{'ns', 'us', 'ms'}}, got {tu}")
+
             return _localize(dt, tz)
         return dt
     else:
