@@ -52,8 +52,18 @@ impl PyLazyGroupBy {
         lgb.tail(Some(n)).into()
     }
 
-    pub fn apply(&mut self, lambda: PyObject) -> PyLazyFrame {
+    pub fn apply(
+        &mut self,
+        lambda: PyObject,
+        schema: Option<Wrap<Schema>>,
+    ) -> PyResult<PyLazyFrame> {
         let lgb = self.lgb.take().unwrap();
+        let schema = match schema {
+            Some(schema) => Arc::new(schema.0),
+            None => LazyFrame::from(lgb.logical_plan.clone())
+                .schema()
+                .map_err(PyPolarsErr::from)?,
+        };
 
         let function = move |df: DataFrame| {
             Python::with_gil(|py| {
@@ -82,7 +92,7 @@ impl PyLazyGroupBy {
                 Ok(pydf.df)
             })
         };
-        lgb.apply(function).into()
+        Ok(lgb.apply(function, schema).into())
     }
 }
 
@@ -337,16 +347,16 @@ impl PyLazyFrame {
         predicate_pushdown: bool,
         projection_pushdown: bool,
         simplify_expr: bool,
-        string_cache: bool,
         slice_pushdown: bool,
+        cse: bool,
     ) -> PyLazyFrame {
         let ldf = self.ldf.clone();
         let ldf = ldf
             .with_type_coercion(type_coercion)
             .with_predicate_pushdown(predicate_pushdown)
             .with_simplify_expr(simplify_expr)
-            .with_string_cache(string_cache)
             .with_slice_pushdown(slice_pushdown)
+            .with_common_subplan_elimination(cse)
             .with_projection_pushdown(projection_pushdown);
         ldf.into()
     }
@@ -378,6 +388,16 @@ impl PyLazyFrame {
         ldf.cache().into()
     }
 
+    pub fn profile(&self, py: Python) -> PyResult<(PyDataFrame, PyDataFrame)> {
+        // if we don't allow threads and we have udfs trying to acquire the gil from different
+        // threads we deadlock.
+        let (df, time_df) = py.allow_threads(|| {
+            let ldf = self.ldf.clone();
+            ldf.profile().map_err(PyPolarsErr::from)
+        })?;
+        Ok((df.into(), time_df.into()))
+    }
+
     pub fn collect(&self, py: Python) -> PyResult<PyDataFrame> {
         // if we don't allow threads and we have udfs trying to acquire the gil from different
         // threads we deadlock.
