@@ -34,6 +34,18 @@ def test_lazy() -> None:
     # test if pl.list is available, this is `to_list` re-exported as list
     df.groupby("a").agg(pl.list("b"))
 
+    # profile lazyframe operation/plan
+    df.lazy().groupby("a").agg(pl.list("b")).profile()
+    # ┌──────────────┬───────┬─────┐
+    # │ node         ┆ start ┆ end │
+    # │ ---          ┆ ---   ┆ --- │
+    # │ str          ┆ u64   ┆ u64 │
+    # ╞══════════════╪═══════╪═════╡
+    # │ optimization ┆ 0     ┆ 6   │
+    # ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌┼╌╌╌╌╌┤
+    # │ groupby(a)   ┆ 6     ┆ 230 │
+    # └──────────────┴───────┴─────┘
+
 
 def test_lazyframe_membership_operator() -> None:
     ldf = pl.DataFrame({"name": ["Jane", "John"], "age": [20, 30]}).lazy()
@@ -891,15 +903,29 @@ def test_arithmetic() -> None:
 
 
 def test_ufunc() -> None:
-    df = pl.DataFrame({"a": [1, 2]})
     # NOTE: unfortunately we must use cast instead of a type: ignore comment
     #   1. CI job with Python 3.10, numpy==1.23.1 -> mypy complains about arg-type
     #   2. so we try to resolve it with type: ignore[arg-type]
     #   3. CI job with Python 3.7, numpy==1.21.6 -> mypy complains about
     #       unused type: ignore comment
     # for more information, see: https://github.com/python/mypy/issues/8823
-    out = df.select(np.log(cast(Any, col("a"))))
-    assert out["a"][1] == 0.6931471805599453
+    df = pl.DataFrame([pl.Series("a", [1, 2, 3, 4], dtype=pl.UInt8)])
+    out = df.select(
+        [
+            np.power(cast(Any, pl.col("a")), 2).alias("power_uint8"),
+            np.power(cast(Any, pl.col("a")), 2.0).alias("power_float64"),
+            np.power(cast(Any, pl.col("a")), 2, dtype=np.uint16).alias("power_uint16"),
+        ]
+    )
+    expected = pl.DataFrame(
+        [
+            pl.Series("power_uint8", [1, 4, 9, 16], dtype=pl.UInt8),
+            pl.Series("power_float64", [1.0, 4.0, 9.0, 16.0], dtype=pl.Float64),
+            pl.Series("power_uint16", [1, 4, 9, 16], dtype=pl.UInt16),
+        ]
+    )
+    assert out.frame_equal(expected)
+    assert out.dtypes == expected.dtypes
 
 
 def test_clip() -> None:
